@@ -1,3 +1,7 @@
+<IfModule mod_dll.c>
+LoadModule perl_module modules/ApacheModulePerl.dll
+</IfModule>
+
 AddType text/x-server-parsed-html .shtml
 AddType text/perl-module .pm
 
@@ -10,15 +14,19 @@ Action text/perl-module /perl/action.pl
 #besides that, we rely on the PerlScript below to set @INC to our blib
 
 PerlScript docs/startup.pl
+PerlScript docs/stacked.pl
+
 #-Tw
 PerlTaintCheck On
 PerlWarn On
 
 PerlSetVar KeyForPerlSetVar OK
+PerlSetEnv KeyForPerlSetEnv OK
 
 <Perl>
 #!perl
-#line 16 httpd.conf
+
+$My::config_is_perl = 1;
 
 use Apache::Constants qw(MODULE_MAGIC_NUMBER);
 use IO::Handle ();
@@ -57,7 +65,7 @@ $ServerName = "localhost";
 
 push @AddType, ["text/x-server-parsed-html" => ".shtml"];
  
-for (qw(/perl/ /cgi-bin/)) {
+for (qw(/perl /cgi-bin)) {
     push @Alias, [$_ => "$dir/net/perl/"];
 }
 
@@ -107,9 +115,8 @@ for (qw(status info)) {
 
 $ErrorLog = "/tmp/mod_perl_error_log";
 $PidFile  = "/tmp/mod_perl_httpd.pid";
-$ResourceConfig = "/tmp/mod_perl_srm.conf";
 
-$AccessConfig = $TypesConfig = $TransferLog = $ScoreBoardFile = "/dev/null";
+$AccessConfig = $TypesConfig = $ScoreBoardFile = "$dir/docs/null.txt";
 
 $LockFile = "/tmp/mod_perl.lock";
 
@@ -130,4 +137,9 @@ $Location{"/stage-redir"} = {
 
 $PerlTransHandler =  "PerlTransHandler::handler";
 
+$Location{"/chain"} = {
+    @mod_perl,
+    PerlHandler => [map { "Stacked::$_" } qw(one two three four)],
+};
+
 </Perl>
